@@ -134,8 +134,11 @@ static void CloseFile(FileHandle file)
         }
         else if (strcmp(result, "ok")!=0)
         {
+            NSString* message;
+            message = [NSString stringWithCString: result
+                                         encoding: NSASCIIStringEncoding];
             NSRunCriticalAlertPanel(@"Error in data file",
-                                    [NSString stringWithCString: result],
+                                    @"%@", message,
                                     @"OK",
                                     nil,
                                     nil);
@@ -395,7 +398,7 @@ static void CloseFile(FileHandle file)
     int ok;
     const int rows = GetRows();
     const int columns = GetColumns();
-    const char method = *([method_string cString]);
+    const char method = *([method_string UTF8String]);
     if (rows==0 || columns==0) {
         [statusbar setStringValue: @"No data available"];
         return;
@@ -443,7 +446,8 @@ static void CloseFile(FileHandle file)
         error = CalculateWeights(gene_cutoff, gene_exponent, genemetric,
                                  array_cutoff, array_exponent, arraymetric);
         if (error) {
-            [statusbar setStringValue: [NSString stringWithCString: error]];
+            [statusbar setStringValue: [NSString stringWithCString: error
+                                        encoding: NSASCIIStringEncoding]];
             return;
         }
     }
@@ -872,7 +876,8 @@ static void CloseFile(FileHandle file)
         CloseFile(coordinatefile);
         CloseFile(pcfile);
         if (error) {
-            [statusbar setStringValue: [NSString stringWithCString: error]];
+            [statusbar setStringValue: [NSString stringWithCString: error
+                                        encoding: NSASCIIStringEncoding]];
             return;
         }
         [statusbar setStringValue: @"Finished Principal Component Analysis"];
@@ -907,7 +912,8 @@ static void CloseFile(FileHandle file)
         CloseFile(coordinatefile);
         CloseFile(pcfile);
         if (error) {
-            [statusbar setStringValue: [NSString stringWithCString: error]];
+            [statusbar setStringValue: [NSString stringWithCString: error
+                                        encoding: NSASCIIStringEncoding]];
             return;
         }
         [statusbar setStringValue: @"Finished Principal Component Analysis"];
