@@ -131,8 +131,6 @@ static char* tokenize(char* s)
     }
     p++;
   }
-  /* Never get here */
-  return NULL;
 }
 
 static char* MakeID(const char* name, int i)
@@ -473,9 +471,10 @@ char* Load(FILE* file)
       free(line);
       fileRow++;
       if (s==NULL)
-      { int n = 1024;
-        char* temp;
-        char* text = malloc(n*sizeof(char));
+      { char* temp;
+        char* text;
+        n = 1024;
+        text = malloc(n*sizeof(char));
         if (!text) return NULL;
         sprintf(text, "Gene name is missing in line %d", fileRow);
 	n = strlen(text) + 1;
@@ -489,9 +488,10 @@ char* Load(FILE* file)
 	return temp;
       }
       if (fileColumn < nFileColumns)
-      { int n = 1024;
-        char* temp;
-        char* text = malloc(n*sizeof(char));
+      { char* temp;
+        char* text;
+        int n = 1024;
+        text = malloc(n*sizeof(char));
         if (!text) return NULL;
         sprintf(text,
                 "Error reading line %d: only %d columns found (%d expected)",
@@ -507,9 +507,10 @@ char* Load(FILE* file)
 	return temp;
       }
       if (fileColumn > nFileColumns)
-      { int n = 1024;
-        char* temp;
-        char* text = malloc(n*sizeof(char));
+      { char* temp;
+        char* text;
+        n = 1024;
+        text = malloc(n*sizeof(char));
         if (!text) return NULL;
         sprintf(text,
                 "Error reading line %d: %d columns given (%d expected)",
@@ -674,7 +675,7 @@ char* Load(FILE* file)
       { char* token = s;
         s = tokenize(s);
         if (fileColumn==0)
-        { const int n = strlen(token) + 1;
+        { n = strlen(token) + 1;
           _geneuniqID[row] = malloc(n*sizeof(char));
           if (!_geneuniqID[row])
           { free(line);
@@ -683,7 +684,7 @@ char* Load(FILE* file)
           strcpy(_geneuniqID[row], token);
         }
         else if (fileColumn==geneNameColumn)
-        { const int n = strlen(token) + 1;
+        { n = strlen(token) + 1;
           _genename[row] = malloc(n*sizeof(char));
           if (!_genename[row])
           { free(line);
