@@ -92,7 +92,7 @@ BOOL SetDlgItemDouble(HWND hwndDlg, int idControl, double dValue)
 { TCHAR szBuffer[32];
   /* Note: wsprintf does not handle floating point values. */
 #ifdef UNICODE
-  swprintf(szBuffer, TEXT("%4g"), dValue);
+  swprintf(szBuffer, 32, TEXT("%4g"), dValue);
 #else
   sprintf(szBuffer, "%4g", dValue);
 #endif
@@ -884,6 +884,8 @@ KmeansDialogProc(HWND hWnd, UINT nMsg, WPARAM wParam, LPARAM lParam)
             int iFoundGenes;
             int iFoundArrays;
 
+            TCHAR buffer[256];
+
             if (!hGeneMetric || !hArrayMetric)
             { MessageBox(NULL,
                          TEXT("Program initialization failed"),
@@ -919,7 +921,6 @@ KmeansDialogProc(HWND hWnd, UINT nMsg, WPARAM wParam, LPARAM lParam)
               int* NodeMap;
               int nGeneTrials;
               ok = 1;
-              TCHAR buffer[256];
 
               kGenes = GetDlgItemInt(hWnd, ID_KMEANS_GENE_K, NULL, FALSE);
               if (kGenes==0)
@@ -990,7 +991,6 @@ KmeansDialogProc(HWND hWnd, UINT nMsg, WPARAM wParam, LPARAM lParam)
               int nArrayTrials;
               int* NodeMap;
               ok = 1;
-              TCHAR buffer[256];
 
               kArrays = GetDlgItemInt(hWnd, ID_KMEANS_ARRAY_K, NULL, FALSE);
               if (kArrays==0)
@@ -1948,7 +1948,7 @@ TEXT("http://bonsai.hgc.jp/~mdehoon/software/cluster/manual"),
 /*  Main                                                                      */
 /*============================================================================*/
 
-int STDCALL
+int WINAPI
 WinMain(HINSTANCE hInst, HINSTANCE hPrev, LPSTR lpCmd, int nShow)
 { /* Show the main window */
   return DialogBox(hInst,
