@@ -41,7 +41,7 @@
 #include "windows.h"
 #include "tchar.h"
 
-int main(int argc, const char* argv[])
+int main(int argc, char* argv[])
 {
   if (argc <= 1) {
     /* Invoked without command-line arguments: start the GUI. */
